@@ -144,6 +144,9 @@ function dynroute_get_config($engine) {
 					if ($item['sourcetype']=='agi') {
 						$query = str_replace('"','\"',$item['agi_query']);
 					}
+					if ($item['sourcetype']=='astvar') {
+						$query = str_replace('"','\"',$item['astvar_query']);
+					}
                                         $query = str_replace('[NUMBER]', '${CALLERID(num)}', $query);
                                         $query = str_replace('[INPUT]', '${dtmfinput}', $query);
                                         $query = str_replace('[DID]', '${FROM_DID}', $query);
@@ -199,6 +202,12 @@ function dynroute_get_config($engine) {
 						if ($item['chan_var_name_res'] != '')
 							$ext->add($id, 's', '', new ext_setvar('__DYNROUTE_'.$item['chan_var_name_res'], '${dynroute}'));
                                         }
+					if ($item['sourcetype']=='astvar' && $item['odbc_func']!='')
+					{
+						$ext->add($id, 's', '', new ext_setvar('dynroute', $query));
+						if ($item['chan_var_name_res'] != '')
+							$ext->add($id, 's', '', new ext_setvar('__DYNROUTE_'.$item['chan_var_name_res'], '${dynroute}'));
+                                        }
 					if ($item['sourcetype']=='none' && $item['enable_dtmf_input']=='CHECKED')
                                         {
                                                 $ext->add($id, 's', '', new ext_setvar('dynroute','${dtmfinput}'));
@@ -259,6 +268,7 @@ function dynroute_do_edit($id, $post) {
         $url_query = $db->escapeSimple($post['url_query']);
         $agi_query = $db->escapeSimple($post['agi_query']);
         $agi_var_name_res = $db->escapeSimple($post['agi_var_name_res']);
+        $astvar_query = $db->escapeSimple($post['astvar_query']);
         $annmsg_id = isset($post['annmsg_id'])?$post['annmsg_id']:'';
         $enable_dtmf_input = isset($post['enable_dtmf_input'])?$post['enable_dtmf_input']:'';
 
@@ -285,6 +295,7 @@ function dynroute_do_edit($id, $post) {
 		url_query='$url_query',
 		agi_query='$agi_query',
 		agi_var_name_res='$agi_var_name_res',
+		astvar_query='$astvar_query',
 		announcement_id='$annmsg_id',  
 		enable_dtmf_input='$enable_dtmf_input',  
 		timeout='$timeout',  
