@@ -193,13 +193,14 @@ function dynroute_show_edit($id, $nbroptions, $post) {
                                 <option value="odbc" <?php echo ($dynroute_details['sourcetype'] == 'odbc' ? 'selected' : '')?>>ODBC</option>
                                 <option value="url" <?php echo ($dynroute_details['sourcetype'] == 'url' ? 'selected' : '')?>>URL</option>
                                 <option value="agi" <?php echo ($dynroute_details['sourcetype'] == 'agi' ? 'selected' : '')?>>AGI</option>
+                                <option value="astvar" <?php echo ($dynroute_details['sourcetype'] == 'astvar' ? 'selected' : '')?>>Asterisk variable</option>
                         </select>
 			</td>
 		</tr>
 
-		<tr>
+		<tr id="urlrow" <?php if ($dynroute_details['sourcetype'] != 'url') echo 'style="display: none"';?>>
 	               <td colspan="2">
-                       <div id="url" <?php if ($dynroute_details['sourcetype'] != 'url') echo 'style="display: none"';?>>
+                       <div id="url"> 
                                 <table cellpadding="2" cellspacing="0" width="100%">
                                         <tr><td colspan="2"><h5><?php echo _("URL") ?><hr></h5></div></td></tr>
                                         </tr>
@@ -211,9 +212,23 @@ function dynroute_show_edit($id, $nbroptions, $post) {
 			</td>
 		</tr>
 
-		<tr>
+		<tr id="astvarrow" <?php if ($dynroute_details['sourcetype'] != 'astvar') echo 'style="display: none"';?>>
 	               <td colspan="2">
-                       <div id="agi" <?php if ($dynroute_details['sourcetype'] != 'agi') echo 'style="display: none"';?>>
+                       <div id="astvar">
+                                <table cellpadding="2" cellspacing="0" width="100%">
+                                        <tr><td colspan="2"><h5><?php echo _("Asterisk variable") ?><hr></h5></div></td></tr>
+                                        </tr>
+                                                <td><a href="#" class="info"><?php echo _("Variable string")?><span><?php echo _("The string containing one or more asterisk variables")?></span></a></td>
+                                                <td><input type="text" name="astvar_query" size="50" value="<?php echo (isset($dynroute_details['astvar_query']) ? htmlentities($dynroute_details['astvar_query']) : ''); ?>" tabindex="<?php echo ++$tabindex;?>"></td>
+                                        </tr>
+				</table>
+			</div>
+			</td>
+		</tr>
+
+		<tr id="agirow" <?php if ($dynroute_details['sourcetype'] != 'agi') echo 'style="display: none"';?>>
+	               <td colspan="2">
+                       <div id="agi">
                                 <table cellpadding="2" cellspacing="0" width="100%">
                                         <tr><td colspan="2"><h5><?php echo _("AGI") ?><hr></h5></div></td></tr>
                                         <tr>
@@ -221,7 +236,7 @@ function dynroute_show_edit($id, $nbroptions, $post) {
                                                 <td><input type="text" name="agi_query" size="50" value="<?php echo (isset($dynroute_details['agi_query']) ? htmlentities($dynroute_details['agi_query']) : ''); ?>" tabindex="<?php echo ++$tabindex;?>"></td>
                                         <tr>
                                         </tr>
-                                                <td><a href="#" class="info"><?php echo _("Result variable")?><span><?php echo _("The name of the variable in the script which must be set with the result. See test.agi for an example.")?></span></a></td>
+                                                <td><a href="#" class="info"><?php echo _("AGI result variable")?><span><?php echo _("The name of the variable in the script which must be set with the result. See test.agi for an example.")?></span></a></td>
                                                 <td><input type="text" name="agi_var_name_res" value="<?php echo (isset($dynroute_details['agi_var_name_res']) ? htmlentities($dynroute_details['agi_var_name_res']) : ''); ?>" tabindex="<?php echo ++$tabindex;?>"></td>
                                         </tr>
 				</table>
@@ -229,9 +244,9 @@ function dynroute_show_edit($id, $nbroptions, $post) {
 			</td>
 		</tr>
 
-		<tr>
+		<tr id="odbcrow" <?php if ($dynroute_details['sourcetype'] != 'odbc') echo 'style="display: none"';?>>
 	               <td colspan="2">
-                       <div id="odbc" <?php if ($dynroute_details['sourcetype'] != 'odbc') echo 'style="display: none"';?>>
+                       <div id="odbc">
                                 <table cellpadding="2" cellspacing="0" width="100%">
                                         <tr><td colspan="2"><h5><?php echo _("ODBC") ?><hr></h5></div></td></tr>
                                         <tr>
@@ -249,9 +264,9 @@ function dynroute_show_edit($id, $nbroptions, $post) {
 
 
 
-		<tr>
+		<tr id="mysqlrow" <?php if ($dynroute_details['sourcetype'] != 'mysql') echo 'style="display: none"';?>>
 	               <td colspan="2">
-                       <div id="mysql" <?php if ($dynroute_details['sourcetype'] != 'mysql') echo 'style="display: none"';?>>
+                       <div id="mysql">
                                 <table cellpadding="2" cellspacing="0" width="100%">
                                         <tr><td colspan="2"><h5><?php echo _("MySQL") ?><hr></h5></div></td></tr>
                                         <tr>
@@ -398,26 +413,42 @@ function drawdestinations($count, $sel,  $dest) {
 <script language="javascript">
 <!--
 function displaySourceParameters(sourcetypeSelect, key) {
-	if (sourcetypeSelect.options[key].value == 'url') {
-                document.getElementById('url').style.display = '';
-                document.getElementById('odbc').style.display = 'none';
-                document.getElementById('agi').style.display = 'none';
-                document.getElementById('mysql').style.display = 'none';
+	if (sourcetypeSelect.options[key].value == 'none') {
+                document.getElementById('urlrow').style.display = 'none';
+                document.getElementById('odbcrow').style.display = 'none';
+                document.getElementById('agirow').style.display = 'none';
+                document.getElementById('astvarrow').style.display = 'none';
+                document.getElementById('mysqlrow').style.display = 'none';
+	} else if (sourcetypeSelect.options[key].value == 'url') {
+                document.getElementById('urlrow').style.display = '';
+                document.getElementById('odbcrow').style.display = 'none';
+                document.getElementById('agirow').style.display = 'none';
+                document.getElementById('astvarrow').style.display = 'none';
+                document.getElementById('mysqlrow').style.display = 'none';
         } else if (sourcetypeSelect.options[key].value == 'agi') {
-                document.getElementById('url').style.display = 'none';
-                document.getElementById('odbc').style.display = 'none';
-                document.getElementById('agi').style.display = '';
-                document.getElementById('mysql').style.display = 'none';
+                document.getElementById('urlrow').style.display = 'none';
+                document.getElementById('odbcrow').style.display = 'none';
+                document.getElementById('agirow').style.display = '';
+                document.getElementById('astvarrow').style.display = 'none';
+                document.getElementById('mysqlrow').style.display = 'none';
+        } else if (sourcetypeSelect.options[key].value == 'astvar') {
+                document.getElementById('urlrow').style.display = 'none';
+                document.getElementById('odbcrow').style.display = 'none';
+                document.getElementById('agirow').style.display = 'none';
+                document.getElementById('astvarrow').style.display = '';
+                document.getElementById('mysqlrow').style.display = 'none';
         } else if (sourcetypeSelect.options[key].value == 'odbc') {
-                document.getElementById('url').style.display = 'none';
-                document.getElementById('odbc').style.display = '';
-                document.getElementById('agi').style.display = 'none';
-                document.getElementById('mysql').style.display = 'none';
+                document.getElementById('urlrow').style.display = 'none';
+                document.getElementById('odbcrow').style.display = '';
+                document.getElementById('agirow').style.display = 'none';
+                document.getElementById('astvarrow').style.display = 'none';
+                document.getElementById('mysqlrow').style.display = 'none';
         } else if (sourcetypeSelect.options[key].value == 'mysql') {
-                document.getElementById('url').style.display = 'none';
-                document.getElementById('odbc').style.display = 'none';
-                document.getElementById('agi').style.display = 'none';
-                document.getElementById('mysql').style.display = '';
+                document.getElementById('urlrow').style.display = 'none';
+                document.getElementById('odbcrow').style.display = 'none';
+                document.getElementById('agirow').style.display = 'none';
+                document.getElementById('astvarrow').style.display = 'none';
+                document.getElementById('mysqlrow').style.display = '';
         }
 }
 -->
